summaryrefslogtreecommitdiff
path: root/lib/multi.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/multi.c')
-rw-r--r--lib/multi.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/lib/multi.c b/lib/multi.c
index 121a44593..b106c9495 100644
--- a/lib/multi.c
+++ b/lib/multi.c
@@ -1642,10 +1642,11 @@ static CURLcode protocol_connect(struct connectdata *conn,
}
/*
* preconnect() is called immediately before a connect starts. When a redirect
* is followed, this is then called multiple times during a single transfer.
*/
-static CURLcode preconnect(struct Curl_easy *data)
+CURLcode Curl_preconnect(struct Curl_easy *data)
{
if(!data->state.buffer) {
data->state.buffer = malloc(data->set.buffer_size + 1);
@@ -1763,7 +1764,7 @@ static CURLMcode multi_runsingle(struct Curl_multi *multi,
case CURLM_STATE_CONNECT:
/* Connect. We want to get a connection identifier filled in. */
/* init this transfer. */
- result = preconnect(data);
+ result = Curl_preconnect(data);
if(result)
break;
@@ -1642,10 +1642,11 @@ static CURLcode protocol_connect(struct connectdata *conn,
}
/*
- * preconnect() is called immediately before a connect starts. When a redirect
- * is followed, this is then called multiple times during a single transfer.
+ * Curl_preconnect() is called immediately before a connect starts. When a
+ * redirect is followed, this is then called multiple times during a single
+ * transfer.
*/